"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServicesBearerTokenVerifyProvider = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const rest_1 = require("@loopback/rest");
const jsonwebtoken_1 = require("jsonwebtoken");
const moment_timezone_1 = tslib_1.__importDefault(require("moment-timezone"));
const logger_extension_1 = require("../../logger-extension");
let ServicesBearerTokenVerifyProvider = class ServicesBearerTokenVerifyProvider {
    constructor(logger) {
        this.logger = logger;
    }
    value() {
        return async (token) => {
            let user;
            try {
                user = jsonwebtoken_1.verify(token, process.env.JWT_SECRET, {
                    issuer: process.env.JWT_ISSUER,
                });
            }
            catch (error) {
                this.logger.error(JSON.stringify(error));
                throw new rest_1.HttpErrors.Unauthorized('TokenExpired');
            }
            if (user.passwordExpiryTime &&
                moment_timezone_1.default().isSameOrAfter(moment_timezone_1.default(user.passwordExpiryTime))) {
                throw new rest_1.HttpErrors.Unauthorized("PasswordExpiryError" /* PasswordExpiryError */);
            }
            return user;
        };
    }
};
ServicesBearerTokenVerifyProvider = tslib_1.__decorate([
    tslib_1.__param(0, context_1.inject(logger_extension_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [Object])
], ServicesBearerTokenVerifyProvider);
exports.ServicesBearerTokenVerifyProvider = ServicesBearerTokenVerifyProvider;
//# sourceMappingURL=services-bearer-token-verify.provider.js.map